@@ -14,6 +14,7 @@ import json
 import logging
 import subprocess
 from subprocess import check_call, CalledProcessError
+import tempfile
 from io import open
 from re import match
 from functools import partial
@@ -537,33 +538,93 @@ class ApplicationBase():
 
     def create_scale_connection(self, conn):
         """Create a Scale connection for retrieving docs using sftp and RSA key."""
-        if conn['online']:
+        if not conn['online']:
+            self.logger.info('Skipping creation of offline scale connection: %s', conn['host'])
+            return
+        if not conn['password']:
+            self.logger.warning('Skipping creation of scale connection: %s due to missing password', conn['host'])
+            return
+
+        try:
+            xport = paramiko.Transport(conn['host'])
+
+            local_conn = False
             try:
-                xport = paramiko.Transport(conn['host'])
+                proc = subprocess.Popen(['/usr/lpp/mmfs/bin/mmlscluster'], stdout=subprocess.PIPE)
+                stdout, _ = proc.communicate()
+                if conn['cluster'] in stdout.decode(ENCODING):
+                    local_conn = True
+            except Exception:
+                pass
 
-                local_conn = False
-                try:
-                    proc = subprocess.Popen(['/usr/lpp/mmfs/bin/mmlscluster'], stdout=subprocess.PIPE)
-                    stdout, _ = proc.communicate()
-                    if conn['cluster'] in stdout.decode(ENCODING):
-                        local_conn = True
-                except Exception:
-                    pass
+            if local_conn:
+                self.connections[(conn['datasource']), conn['cluster']] = ('Spectrum Scale Local', conn)
+                self.logger.info('Successfully created local scale connection for: %s', conn['name'])
+                return
 
-                if local_conn:
-                    self.connections[(conn['datasource']), conn['cluster']] = ('Spectrum Scale Local', conn)
-                    self.logger.info('Successfully created local scale connection for: %s', conn['name'])
-                    return
+            xport.connect(username=conn['user'], password=self.cipher.decrypt(conn['password']))
+            sftp = paramiko.SFTPClient.from_transport(xport)
+            if sftp:
+                self.connections[(conn['datasource']), conn['cluster']] = ('Spectrum Scale', sftp)
+                self.logger.info('Successfully created scale connection for: %s', conn['name'])
 
-                xport.connect(username=conn['user'], password=self.cipher.decrypt(conn['password']))
-                sftp = paramiko.SFTPClient.from_transport(xport)
-                if sftp:
-                    self.connections[(conn['datasource']), conn['cluster']] = ('Spectrum Scale', sftp)
-                    self.logger.info('Successfully created scale connection for: %s', conn['name'])
+        except (paramiko.ssh_exception.BadHostKeyException, paramiko.ssh_exception.AuthenticationException,
+                paramiko.ssh_exception.SSHException, paramiko.ssh_exception.NoValidConnectionsError) as ex:
+            self.logger.warning('Error when attempting Scale connection: %s', str(ex))
 
-            except (paramiko.ssh_exception.BadHostKeyException, paramiko.ssh_exception.AuthenticationException,
-                    paramiko.ssh_exception.SSHException, paramiko.ssh_exception.NoValidConnectionsError) as ex:
-                self.logger.warning('Error when attempting Scale connection: %s', str(ex))
+    def mount_smb(self, conn, local_mount):
+        """Mount the SMB file system."""
+        if not conn['host']:
+            self.logger.warning('Host not defined so cannot create SMB mount.')
+            return
+        if not conn['user']:
+            self.logger.warning('Could not retrieve SMB user.')
+            return
+        if not conn['password']:
+            self.logger.warning('Could not retrieve password for SMB mount.')
+            return
+        if not conn['mount_point']:
+            self.logger.warning('Could not retrieve smb export path.')
+            return
+        if not local_mount:
+            self.logger.warning('Host mount path could not be created.')
+            return
+
+        host = conn['host']
+        password = self.cipher.decrypt(conn['password'])
+        export_path = conn['mount_point']
+
+        if '\\' in conn['user']:
+            (domain, user) = conn['user'].split('\\')
+        elif '/' in conn['user']:
+            (domain, user) = conn['user'].split('/')
+        elif '@' in conn['user']:
+            (user, domain) = conn['user'].split('@')
+        else:
+            (domain, user) = ('', conn['user'])
+
+        cmd = f'mount -t cifs {export_path} {local_mount} -o user={user} -o password={password} -o ro'
+        if domain:
+            cmd += f' -o domain={domain}'
+
+        try:
+            check_call(cmd, shell=True)
+        except CalledProcessError:
+            # Not fatal, this might not be an active connection
+            self.logger.warning('Failed to mount SMB export %s', host)
+
+    def create_smb_connection(self, conn):
+        """Create a SMB connection for retrieving docs using a cifs mount."""
+        prefix = 'smb_'
+        suffix = '_' + conn['name'] + '_' + conn['datasource']
+        local_mount = tempfile.mkdtemp(suffix=suffix, prefix=prefix)
+
+        conn['additional_info'] = {}
+        conn['additional_info']['local_mount'] = local_mount
+
+        self.mount_smb(conn, local_mount)
+        self.connections[(conn['datasource']), conn['cluster']] = ('SMB/CIFS', conn)
+        self.logger.info('Successfully created smb connection for: %s', conn['name'])
 
     def connect_to_datasources(self):
         """Loop through datasources and create connections."""
@@ -575,6 +636,8 @@ class ApplicationBase():
                 self.create_nfs_connection(conn)
             elif conn['platform'] == "Spectrum Scale":
                 self.create_scale_connection(conn)
+            elif conn['platform'] == "SMB/CIFS":
+                self.create_smb_connection(conn)
             else:
                 self.logger.warning("Unsupported connection platform %s", conn['platform'])
 
